//
//  ExampleDataSession.swift
//  URLSessionDemo
//
//  Created by Sarah Abraham on 9/28/16.
//  Copyright © 2016 Sarah Abraham. All rights reserved.
//

import UIKit

protocol ExampleDataProtocol
{
    func responseDataHandler(data:NSDictionary)
    func responseError(message:String)
}

class ExampleDataSession {
    private let urlSession = URLSession.shared
    private let urlPathBase = "http://jsonplaceholder.typicode.com/posts/"
    
    private var dataTask:URLSessionDataTask? = nil
    
    var delegate:ExampleDataProtocol? = nil
    
    init() {}
    
    func getData(exampleDataNumber:String) {
        
        var urlPath = self.urlPathBase
        urlPath = urlPath + exampleDataNumber
        
        let url:NSURL? = NSURL(string: urlPath)
        
        let dataTask = self.urlSession.dataTask(with: url! as URL) { (data, response, error) -> Void in
            if error != nil {
                print(error!)
            } else {
                do {
                    let jsonResult = try JSONSerialization.jsonObject(with: data!, options: JSONSerialization.ReadingOptions.mutableContainers) as? NSDictionary
                    if jsonResult != nil {
                        //print(jsonResult)
                        let title: String? = jsonResult!["title"] as? String
                        let body: String? = jsonResult!["body"] as? String
                        if title != nil && body != nil {
                            self.delegate?.responseDataHandler(data: jsonResult!)
                        } else {
                            self.delegate?.responseError(message: "Fake data not found")
                        }
                    }
                } catch {
                    //Catch and handle the exception
                }
            }
        }
        dataTask.resume()
    }
    
}
